@@ -76,10 +76,18 @@ class DbusManager(dbus.service.Object):
     def get_selected_tab(self):
         return self.guake.get_selected_tab()
 
+    @dbus.service.method(DBUS_NAME, out_signature='s')
+    def get_selected_tablabel(self):
+        return self.guake.get_selected_tablabel()
+
     @dbus.service.method(DBUS_NAME, out_signature='i')
     def get_tab_count(self):
         return len(self.guake.notebook.term_list)
 
+    @dbus.service.method(DBUS_NAME, in_signature='s')
+    def set_bg_image(self, bgcolor):
+        self.guake.set_bg_image(bgcolor)
+
     @dbus.service.method(DBUS_NAME, in_signature='s')
     def set_bgcolor(self, bgcolor):
         self.guake.set_bgcolor(bgcolor)
