@@ -299,6 +299,23 @@ class Guake(SimpleGladeApp):
         self.abbreviate = False
         self.was_deleted_tab = False
 
+        def tabs_scrollbar_hide(hscrollbar):
+            self.get_widget('event-tabs').set_property('height_request', 10)
+            if self.abbreviate and self.was_deleted_tab:
+                self.was_deleted_tab = False
+                self.abbreviate = False
+                self.recompute_tabs_titles()
+
+        def tabs_scrollbar_show(hscrollbar):
+            self.get_widget('event-tabs').set_property('height_request', -1)
+            if self.client.get_bool(KEY("/general/abbreviate_tab_names")):
+                self.abbreviate = True
+                self.recompute_tabs_titles()
+
+        tabs_scrollbar = self.get_widget('tabs-scrolledwindow').get_hscrollbar()
+        tabs_scrollbar.connect('hide', tabs_scrollbar_hide)
+        tabs_scrollbar.connect('show', tabs_scrollbar_show)
+
         # Flag to prevent guake hide when window_losefocus is true and
         # user tries to use the context menu.
         self.showing_context_menu = False
@@ -711,7 +728,15 @@ class Guake(SimpleGladeApp):
             self.selected_tab = target
             menu = self.get_widget('tab-menu')
             menu.popup(None, None, None, 3, event.get_time())
-        self.set_terminal_focus()
+
+        """This may look like it could be refactored by just calling self.set_terminal_focus()
+        but self.set_terminal_focus() calls self.get_selected_tab() which overrides the
+        value of self.selected_tab
+        """
+        self.notebook.get_current_terminal().grab_focus()
+        pos = self.notebook.get_current_page()
+        self.select_tab(0)
+        self.select_tab(pos)
 
     def middle_button_click(self, target, event):
         """Closes a tab with a middle click
@@ -758,9 +783,10 @@ class Guake(SimpleGladeApp):
             return
 
         event_time = self.hotkeys.get_current_event_time()
-
-        if self.client.get_bool(KEY('/general/focus_if_open')) and \
-                not self.client.get_bool(KEY('/general/window_losefocus')):
+        if not self.client.get_bool(KEY('/general/window_refocus')) and \
+                self.window.window and self.window.get_property('visible'):
+            pass
+        elif not self.client.get_bool(KEY('/general/window_losefocus')):
             if self.losefocus_time and self.losefocus_time < event_time:
                 if self.window.window and self.window.get_property('visible'):
                     log.debug("DBG: Restoring the focus to the terminal")
