@@ -30,6 +30,7 @@ import logging
 import os
 import subprocess
 import sys
+import uuid
 
 from optparse import OptionParser
 
@@ -40,6 +41,7 @@ from guake.dbusiface import DBUS_NAME
 from guake.dbusiface import DBUS_PATH
 from guake.dbusiface import DbusManager
 from guake.globals import KEY
+from guake.globals import VERSION
 from guake.guake_app import Guake
 
 
@@ -61,7 +63,7 @@ def main():
     # Force to xterm-256 colors for compatibility with some old command line programs
     os.environ["TERM"] = "xterm-256color"
 
-    parser = OptionParser()
+    parser = OptionParser(version='Guake Terminal %s' % VERSION)
     parser.add_option('-f', '--fullscreen', dest='fullscreen',
                       action='store_true', default=False,
                       help=_('Put Guake in fullscreen mode'))
@@ -98,6 +100,10 @@ def main():
                       action='store_true', default=False,
                       help=_('Return the selected tab index.'))
 
+    parser.add_option('-l', '--selected-tablabel', dest='selected_tablabel',
+                      action='store_true', default=False,
+                      help=_('Return the selected tab label.'))
+
     parser.add_option('-e', '--execute-command', dest='command',
                       action='store', default='',
                       help=_('Execute an arbitrary command in the selected tab.'))
@@ -106,6 +112,11 @@ def main():
                       action='store', default='0',
                       help=_('Specify the tab to rename. Default is 0.'))
 
+    parser.add_option('--bgimg', dest='bgimg',
+                      action='store', default='',
+                      help=_('Set the background image of '
+                             'the selected tab.'))
+
     parser.add_option('--bgcolor', dest='bgcolor',
                       action='store', default='',
                       help=_('Set the hexadecimal (#rrggbb) background color of '
@@ -183,12 +194,24 @@ def main():
         sys.stdout.write('%d\n' % selected)
         only_show_hide = False
 
+    if options.selected_tablabel:
+        selectedlabel = remote_object.get_selected_tablabel()
+        sys.stdout.write('%s\n' % selectedlabel)
+        only_show_hide = False
+
     if options.command:
         remote_object.execute_command(options.command)
         only_show_hide = False
 
     if options.tab_index and options.rename_tab:
-        remote_object.rename_tab(int(options.tab_index), options.rename_tab)
+        try:
+            remote_object.rename_tab_uuid(str(uuid.UUID(options.tab_index)), options.rename_tab)
+        except ValueError:
+            remote_object.rename_tab(int(options.tab_index), options.rename_tab)
+        only_show_hide = False
+
+    if options.bgimg:
+        remote_object.set_bg_image(options.bgimg)
         only_show_hide = False
 
     if options.bgcolor:
